'use strict';

var useSsl = false;

function getDevDesktopBasePath() {
  // Check for a running Dev Desktop instance and grab it's path. There can be 
  // multiple Dev Desktop applications registered, but we only want the active
  // one.
  var spawn = require('child_process').spawnSync;
  var cmd = spawn('/bin/ps', ['-o command', '-A'], {encoding: 'utf8'});

  if (!cmd.error) {
    var psOutput = cmd.stdout.split('\n');
    var devDesktopSearchString = '/Acquia Dev Desktop.app/';
    var command = '';
    var commandSearchIndex = -1;

    for (var lineIndex in psOutput) {
      command = psOutput[lineIndex];
      commandSearchIndex = command.search(devDesktopSearchString);
      if (commandSearchIndex >= 0) {
        break;
      }
    }

    var path = command.substring(0, commandSearchIndex + devDesktopSearchString.length - 1);

    return path;
  } else {
    return false;
  }
}

function getApachePort(devDesktopBasePath, useSsl) {
  if (useSsl === undefined) {
    useSsl = false;
  }

  var fs = require('fs');
  var parseString = require('xml2js').parseString;
  var xmlDynamicFile = devDesktopBasePath + '/Contents/MacOs/dynamic.xml';

  // Read in the XML file as a string.
  var fileContents = fs.readFileSync(xmlDynamicFile, 'utf8');
  var port = null;

  parseString(fileContents, function (err, result) {
    var services = result.root.dcfg[0].services[0];

    if (useSsl) {
      port = services.apachePortHttps[0];
    } else {
      port = services.apachePort[0];
    }
  });

  return port;
}

function getHostnameFromXml(devDesktopBasePath, port) {
  var fs = require('fs');
  var parseString = require('xml2js').parseString;
  var xmlDataModelFile = devDesktopBasePath + '/Contents/MacOS/datamodel.xml';

  // Read in the XML file as a string.
  var fileContents = fs.readFileSync(xmlDataModelFile, 'utf8');

  var hostname = null;

  parseString(fileContents, function (err, result) {
    var items = result.root.datamodel[0].codebases[0].codebases[0].item;

    for (var i = items.length - 1; i >= 0; i--) {
      var item = items[i];
      var docRoot = item.docRoot;

      // Compare docRoot to this source files current path.
      if (docRoot[0] == __filename.substring(0, docRoot[0].length)) {
        // Build the full URL for the local domain name.
        hostname = 'http://' + item.sites[0].item[0].host + ':' + port;
        break;
      }
    }
  });


  return hostname;
}


var devDesktopBasePath = getDevDesktopBasePath();
var apachePort = getApachePort(devDesktopBasePath, useSsl);
var hostname = getHostnameFromXml(devDesktopBasePath, apachePort);

module.exports = hostname;
